pub enum NestedBlock {
Single(Block),
List(Block),
Set(Block),
Map(Block),
Group(Block),
Optional(Block),
}Expand description
NestedBlock
Variants
Single(Block)
The nested block must appear exactly once
List(Block)
The nested block can appear multiple times
Set(Block)
The nested block can appear multiple times (unordered)
Map(Block)
The nested block can appear multiple times and have names
Group(Block)
The nested block can appear at most once (if not given, it will be populate with Nulls)
Optional(Block)
The nested block can appear at most once (if not given, it will be null)
This is implemented with a list block, and must be serialized with value::serde_as_vec
use tf_provider::value::{self, Value};
#[derive(Serialize, Deserialize)]
struct MyBlock {
/* ... */
}
#[derive(Serialize, Deserialize)]
struct MyState {
#[serde(with = "value::serde_as_vec")]
my_block: Value<MyBlock>,
}