AttributePath

Struct AttributePath 

pub struct AttributePath {
    pub steps: Vec<AttributePathStep>,
}
Represent the path to an attribute

Example

let path = AttributePath::new("foo").key("bar").attribute("array").index(1);
// foo["bar"].array[1]

Fields

steps: Vec<AttributePathStep>

Implementations

Source

impl AttributePath

pub fn new<T: Into<Cow<'static, str>>>(name: T) -> Self

Create a new attribute path with the root attribute

Arguments
  • name - Name of the root attribute
pub fn root() -> Self

Create a new attribute path without any path component

pub fn function_argument(index: i64) -> Self

Create a new attribute path for a function argument

Arguments
  • index - index of the function argument
pub fn attribute<T: Into<Cow<'static, str>>>(self, name: T) -> Self

Create a new attribute path where the attribute .name has been appended

Arguments
  • name - name of the attribute
pub fn key<T: Into<Cow<'static, str>>>(self, key: T) -> Self

Create a new attribute path where the access ["key"] has been appended

Arguments
  • key - string subscript
pub fn index<T: Into<i64>>(self, idx: T) -> Self

Create a new attribute path where the access [idx] has been appended

Arguments
  • idx - integer subscript
pub fn add_attribute<T: Into<Cow<'static, str>>>( &mut self, name: T, ) -> &mut Self

Add name access to the path (ie: .name)

Arguments
  • name - name of the attribute
pub fn add_key<T: Into<Cow<'static, str>>>(&mut self, key: T) -> &mut Self

add key access to the path (ie: ["key"])

Arguments
  • key - string subscript
pub fn add_index<T: Into<i64>>(&mut self, idx: T) -> &mut Self

add index access to the path (ie: [idx])

Arguments
  • idx - integer subscript
pub fn add_step(&mut self, step: AttributePathStep) -> &mut Self

Add step to the path

Arguments
  • step - step to add
pub fn add_steps(&mut self, steps: AttributePath) -> &mut Self

Add multiple steps into the path

Arguments
  • steps - steps to add